(function() {
    // xg.js
    
    
    let margin = {top: 20, right: 30, bottom: 50, left: 150}; // Ajustamos los márgenes para espacio en el eje Y
    let width = 800 - margin.left - margin.right;
    let height = 370 - margin.top - margin.bottom;
    
    let x = d3.scaleLinear().range([0, width]);
    let y = d3.scaleBand().range([0, height]).padding(0.1);
    let color = d3.scaleOrdinal(d3.schemeCategory10);
    

    // Contenedor para la leyenda
    let legendContainer = d3.select("#tab1")
        .append("div")
        .attr("id", "legendContainer")
        .style("position", "absolute")
        .style("top", "160px")
        .style("left", "850px")
        .style("width", "80px")
        .style("height", "300px")
        .style("border", "2px solid black")
        .style("padding", "10px")
        .style("background-color", "#f0f0f0");

    legendContainer.html(`
        <h3>Leyenda</h3>
        <p><span style="color: blue;">●</span> Goles anotados</p>
        <p><span style="color: red;">●</span> xG (Expected Goals)</p>
        <p><span style="color: blue;">──</span> Goles>xG</p>
        <p><span style="color: red;">──</span> xG>Goles</p>
    `);


    // Contenedor SVG
    let svgContainer = d3.select("#tab1"); // Contenedor específico para la pestaña
    let svg;
    
    let data; // Variable global para los datos
    
    window.infoContainer = d3.select("body")
    .append("div")
    .attr("id", "infoContainer")
    .style("position", "absolute")
    .style("top", 160 + "px")
    .style("left", (width + margin.left + margin.right + 160) + "px")
    .style("width", "260px")
    .style("height", "400px")
    .style("border", "4px solid black")
    .style("padding", "10px")
    .style("background-color", "#f9f9f9")
    .style("display", "block") // Siempre visible
    .html(`<h1>Haz clic en una línea para ver detalles.</h1>`); // Mensaje predeterminado
    // Cargar datos desde el CSV
    d3.csv("./understat.com.csv").then(function(loadedData) {
        console.log("Datos cargados:", loadedData); // Depuración: verificar datos cargados
        data = loadedData.map(d => {
            d.scored = +d.scored;
            d.xG = +d.xG;
            d.xG_diff = +d.xG_diff; // Asegurarnos de que xG_diff sea numérico
            d.xpts = +d.xpts;
            
            return d;
        });
    
        console.log("Datos procesados:", data); // Depuración: verificar datos procesados
    
        // Inicializar con valores por defecto
        updateGraph(2014, "La_liga");
    
        // Evento para cambiar el gráfico cuando se selecciona un año
        d3.select("#yearSelector1").on("change", function() {
            let selectedYear = +this.value;
            let selectedTrophie = d3.select("#trophieSelector1").node().value;
            updateGraph(selectedYear, selectedTrophie);
        });
    
        // Evento para cambiar el gráfico cuando se selecciona una liga
        d3.select("#trophieSelector1").on("change", function() {
            let selectedYear = +d3.select("#yearSelector1").node().value;
            let selectedTrophie = this.value;
            updateGraph(selectedYear, selectedTrophie);
        });
    
    }).catch(function(error) {
        console.error("Error al cargar el archivo CSV:", error);
    });
    
    function updateGraph(year, trophie) {
        console.log(`Actualizar gráfico: Año=${year}, Liga=${trophie}`); // Depuración: parámetros seleccionados

        // Filtrar los datos según el año y la liga seleccionados
        let filteredData = data.filter(d => +d.Year === year && d.Trophie === trophie);
    
        console.log("Datos filtrados:", filteredData); // Depuración: verificar datos filtrados
    
        if (filteredData.length === 0) {
            console.warn("No se encontraron datos para los filtros seleccionados.");
        }
    
        // Ordenar los datos por la columna scored de mayor a menor
        filteredData.sort((a, b) => b.scored - a.scored);
    
        // Eliminar el SVG existente si ya está presente
        svgContainer.select("svg").remove(); // Asegura que sólo exista un gráfico por pestaña
    
        // Crear un nuevo título
        svgContainer.select("h2").remove(); // Eliminar título anterior si existe
        svgContainer.append("h2")
            .text(`xG vs Goles anotados: ${trophie} ${year}-${year + 1}`)
            .style("text-align", "center-left")
            .style("margin-bottom", "10px");
    
        // Crear un nuevo SVG
        svg = svgContainer
            .append("svg")
            .attr("width", width + margin.left + margin.right)
            .attr("height", height + margin.top + margin.bottom)
          .append("g")
            .attr("transform", "translate(" + margin.left + "," + margin.top + ")");
    
        // Configurar dominios de las escalas
        x.domain([0, d3.max(filteredData, d => Math.max(d.scored, d.xG))]);
        y.domain(filteredData.map(d => d.team));
    
        // Dibujar ejes
        svg.append("g")
            .attr("transform", `translate(0,${height})`)
            .call(d3.axisBottom(x).ticks(5));
    
        svg.append("g")
            .call(d3.axisLeft(y));
    
        // Dibujar líneas desde el eje Y hasta el final del eje X
        svg.selectAll(".team-line")
            .data(filteredData)
            .enter()
            .append("line")
            .attr("class", "team-line")
            .attr("x1", 0) // Desde el inicio del eje X
            .attr("y1", d => y(d.team) + y.bandwidth() / 2) // Centrado en la banda del equipo
            .attr("x2", width) // Hasta el final del eje X
            .attr("y2", d => y(d.team) + y.bandwidth() / 2) // Mantener alineación
            .attr("stroke", "lightgray") // Color de la línea
            .attr("stroke-width", 1) // Grosor de la línea
            .attr("stroke-dasharray", "4,2"); // Línea punteada

        // Añadir el texto sobre el fondo
        svg.append("text")
            .attr("x", width / 2)
            .attr("y", height + 40)
            .attr("text-anchor", "middle")
            .attr("font-weight", "bold") // Texto en negrita
            .attr("font-size", "24px") // Tamaño mayor
            .attr("fill", "black") // Color del texto (negro)
            .text("Goles");


        // Añadir el texto sobre el fondo
        svg.append("text")
            .attr("transform", "rotate(-90)") // Rota el texto
            .attr("x", -height / 2)
            .attr("y", -120)
            .attr("text-anchor", "middle")
            .attr("font-weight", "bold") // Aplica la negrita
            .attr("font-size", "24px") // Ajusta el tamaño del texto
            .attr("fill", "black") // Color del texto (negro)
            .text("Equipo");


        svg.selectAll(".line")
            .data(filteredData)
            .enter()
            .append("line")
            .attr("class", "line")
            .attr("x1", d => x(d.scored))
            .attr("y1", d => y(d.team)+8)
            .attr("x2", d => x(d.xG))
            .attr("y2", d => y(d.team)+8)
            .attr("stroke", d => d.xG_diff > 0 ? "blue" : "red")
            .attr("stroke-width", 6)
            .on("click", function(event, d) {
                infoContainer
                    .style("display", "block")
                    .html(`
                        <h1>${d.team}</h1>
                        <p><strong>Posición en liga:</strong> ${d.position}</p>
                        <p><strong>Partidos jugados:</strong> ${d.matches}</p>
                        <p><strong>Victorias/empates/derrotas:</strong> ${d.wins}/${d.draws}/${d.loses}</p>
                        <p><strong>Goles:</strong> ${d.scored}</p>
                        <p><strong>xG:</strong> ${d.xG.toFixed(2)}</p>
                        <p><strong>Diferencia Goles-xG:</strong> ${d.xG_diff.toFixed(2)}</p>
                        <p><strong>Puntos:</strong> ${d.pts}
                        <p><strong>Puntos esperados:</strong> ${d.xpts.toFixed(2)}</p>
                    `);
            });

        // Dibujar los puntos de "scored" y "xG" y las líneas de conexión
        svg.selectAll(".dot-scored")
            .data(filteredData)
            .enter()
            .append("circle")
            .attr("class", "dot-scored")
            .attr("cx", d => x(d.scored))
            .attr("cy", d => y(d.team)+8)
            .attr("r", 8)
            .style("fill", "blue")
            .on("click", function(event, d) {
                infoContainer
                    .style("display", "block")
                    .html(`
                        <h1>${d.team}</h1>
                        <p><strong>Posición en liga:</strong> ${d.position}</p>
                        <p><strong>Partidos jugados:</strong> ${d.matches}</p>
                        <p><strong>Victorias/empates/derrotas:</strong> ${d.wins}/${d.draws}/${d.loses}</p>
                        <p><strong>Goles:</strong> ${d.scored}</p>
                        <p><strong>xG:</strong> ${d.xG.toFixed(2)}</p>
                        <p><strong>Diferencia Goles-xG:</strong> ${d.xG_diff.toFixed(2)}</p>
                        <p><strong>Puntos:</strong> ${d.pts}
                        <p><strong>Puntos esperados:</strong> ${d.xpts.toFixed(2)}</p>
                    `);
            });
    
        svg.selectAll(".dot-xg")
            .data(filteredData)
            .enter()
            .append("circle")
            .attr("class", "dot-xg")
            .attr("cx", d => x(d.xG))
            .attr("cy", d => y(d.team)+8)
            .attr("r", 8)
            .style("fill", "red")
            .on("click", function(event, d) {
                infoContainer
                    .style("display", "block")
                    .html(`
                        <h1>${d.team}</h1>
                        <p><strong>Posición en liga:</strong> ${d.position}</p>
                        <p><strong>Partidos jugados:</strong> ${d.matches}</p>
                        <p><strong>Victorias/empates/derrotas:</strong> ${d.wins}/${d.draws}/${d.loses}</p>
                        <p><strong>Goles:</strong> ${d.scored}</p>
                        <p><strong>xG:</strong> ${d.xG.toFixed(2)}</p>
                        <p><strong>Diferencia Goles-xG:</strong> ${d.xG_diff.toFixed(2)}</p>
                        <p><strong>Puntos:</strong> ${d.pts}
                        <p><strong>Puntos esperados:</strong> ${d.xpts.toFixed(2)}</p>
                    `);
            });


            
    
        
    }
    
    })();
    